@@ -157,7 +157,10 @@ battfink_apm_read_info (BattfinkApm *battfink_apm, GError **error)
 #ifdef HAVE_APM
   struct apm_info battery_info;
   int apm_ret;
-  apm_ret = apm_read (&battery_info);
+  if (battfink_acpi_read_info (&battery_info))
+    apm_ret = 0;
+  else
+    apm_ret = apm_read (&battery_info);
 
   switch (apm_ret) {
     case 0:
@@ -211,12 +214,21 @@ static gchar *
 battfink_apm_get_time (BattfinkApm *battfink_apm)
 { 
   if (battfink_apm->priv->show_time) {
-    if (battfink_apm->priv->battery_time / 60 == 0)
+    if (battfink_apm->priv->battery_time == 0)
       return g_strdup_printf ("");
-    else
-      return g_strdup_printf (_("%d:%d"),
-                              battfink_apm->priv->battery_time / 60,
-                              battfink_apm->priv->battery_time % 60);
+    else {
+      /* We have to pad the time with a zero */
+      if ((battfink_apm->priv->battery_time % 60) < 10) {
+        return g_strdup_printf (_("%d:0%d"),
+                                battfink_apm->priv->battery_time / 60,
+                                battfink_apm->priv->battery_time % 60);
+      }
+      else {
+        return g_strdup_printf (_("%d:%d"),
+                                battfink_apm->priv->battery_time / 60,
+                                battfink_apm->priv->battery_time % 60);
+      }
+    }
   }
   else
     return g_strdup_printf (_("%d %%"),
@@ -258,11 +270,20 @@ static gboolean
 battfink_apm_update_image (BattfinkApm *battfink_apm)
 {
   static gboolean first_time = FALSE;
+  static gboolean changed_time = FALSE;
   GError *error = NULL;
 
+  if (!battfink_apm->priv->ac_power && changed_time) {
+    changed_time = FALSE;
+    battfink_apm->priv->show_time = TRUE;
+  }
+
+  /* Convert to % while charging */
   if (battfink_apm->priv->ac_power) {
-    if (battfink_apm->priv->show_time)
+    if (battfink_apm->priv->show_time) {
       battfink_apm->priv->show_time = FALSE;
+      changed_time = TRUE; 
+    }
   }
 
   battfink_apm_read_info (battfink_apm, &error);
@@ -513,6 +534,7 @@ battfink_apm_change_label_callback (GtkWidget *widget, gpointer user_data)
 
   battfink_apm = BATTFINK_APM (user_data);
   show_time = gtk_check_menu_item_get_active (GTK_CHECK_MENU_ITEM (battfink_apm->priv->time_menu_item));
+
   if (show_time)
     battfink_apm->priv->show_time = TRUE;
   else
